==> gnats_3.113.orig.tar.gz: gnats-3.113.orig/gnats/mkcat.sh <==
#!/bin/sh
# Create directories for each category in a GNATS categories file. 
# Copyright (C) 1993, 1994, 1995 Free Software Foundation, Inc.
# Contributed by Brendan Kehoe (brendan@cygnus.com) and
# Tim Wicinski (wicinski@barn.com).
#
# This file is part of GNU GNATS.
#
# GNU GNATS is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
#
# GNU GNATS is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with GNU GNATS; see the file COPYING.  If not, write to
# the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

prog=`basename $0`
USAGE="$prog: [--help] [--directory=gnats_root]"

# process command line options
while [ $# -gt 0 ]; do
  case "$1" in
    -d | --directory)
      if [ $# -eq 1 ]; then echo "$USAGE"; exit 1; fi
      shift ; GNATS_ROOT="$1" ;;
    --directory=*) GNATS_ROOT="`echo $1 | sed 's/^[-a-z]*=//'`" ;;
    -*)  echo "$USAGE" ; exit 1 ;;
  esac
  shift
done

errmsg="must be set in the environment or on command line

$USAGE"

GNATS_ROOT=${GNATS_ROOT:?$errmsg}
GNATS_SITE=xGNATS_SITEx
DATADIR=xDATADIRx

# verify gnats root
if [ ! -d ${GNATS_ROOT} ] ; then
   echo "$prog: No GNATS_ROOT directory $GNATS_ROOT!"
   exit 1
fi


CATEGORIES=`grep -v '^#' $GNATS_ROOT/gnats-adm/categories | sed -e 's/:.*//g'`

# Newer config information?
[ -f ${GNATS_ROOT}/gnats-adm/config ] && . ${GNATS_ROOT}/gnats-adm/config

if [ ! -d $DATADIR/gnats ]; then
  echo "$prog: No directory $DATADIR/gnats!"
  exit 1
fi

if [ ! -d $DATADIR/gnats/dist ]; then
  echo "$prog: No directory $DATADIR/gnats/dist!"
  exit 1
fi

rm -f $DATADIR/gnats/dist/categories $DATADIR/gnats/$GNATS_SITE
cp /dev/null $DATADIR/gnats/dist/categories
cp /dev/null $DATADIR/gnats/$GNATS_SITE

for i in $CATEGORIES; do
    
    if test -d $GNATS_ROOT/$i; then
	true
    else
	mkdir $GNATS_ROOT/$i
        echo creating category $GNATS_ROOT/$i
    fi

    echo $i >> $DATADIR/gnats/dist/categories
    echo $i >> $DATADIR/gnats/$GNATS_SITE

done

exit 0

==> gnats-3.999.1.tar.gz: gnats-3.999.1/gnats/mkcat.sh <==
#!/bin/sh
# Create directories for each category in a GNATS categories file. 
# Copyright (C) 1993, 1994, 1995 Free Software Foundation, Inc.
# Contributed by Brendan Kehoe (brendan@cygnus.com) and
# Tim Wicinski (wicinski@barn.com).
#
# This file is part of GNU GNATS.
#
# GNU GNATS is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
#
# GNU GNATS is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with GNU GNATS; see the file COPYING.  If not, write to
# the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

prog=mkcat
USAGE="Usage: $prog [--help] [--database=databasename]"

# process command line options
while [ $# -gt 0 ]; do
  case "$1" in
    -d | --database)
      if [ $# -eq 1 ]; then echo "$USAGE"; exit 1; fi
      shift ; GNATSDB="$1" ; export GNATSDB ;;
    --database=*) GNATSDB="`echo $1 | sed 's/^[-a-z]*=//'`" ; export GNATSDB ;;
    -*)  echo "$USAGE" ; exit 1 ;;
  esac
  shift
done


GNATS_DB_DIR="`query-pr --print-directory-for-database`"

# verify gnats root
if [ ! -d ${GNATS_DB_DIR} ] ; then
   echo "$prog: No directory $GNATS_DB_DIR"
   exit 1
fi

query-pr --list-categories | awk -F: '{print $1}' | while read i
do
    if test -d "$GNATS_DB_DIR/$i"; then
	true
    else
	mkdir "$GNATS_DB_DIR/$i"
        echo "Category \`$GNATS_DB_DIR/$i' created."
    fi
done

exit 0
